==> kubernetes-model-apiextensions-4.13.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionVersionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionVersionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<A>> extends Fluent<A> {


    public A addToAdditionalPrinterColumns(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> items);
    public A removeMatchingFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean hasMatchingAdditionalPrinterColumn(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean isDeprecated();
    public A withDeprecated(Boolean deprecated);
    public Boolean hasDeprecated();
    public A withNewDeprecated(String arg1);
    public A withNewDeprecated(boolean arg1);
    public String getDeprecationWarning();
    public A withDeprecationWarning(String deprecationWarning);
    public Boolean hasDeprecationWarning();
    public A withNewDeprecationWarning(String arg1);
    public A withNewDeprecationWarning(StringBuilder arg1);
    public A withNewDeprecationWarning(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation getSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation buildSchema();
    public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation schema);
    public Boolean hasSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation item);
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation item);
    public Boolean isServed();
    public A withServed(Boolean served);
    public Boolean hasServed();
    public A withNewServed(String arg1);
    public A withNewServed(boolean arg1);
    public Boolean isStorage();
    public A withStorage(Boolean storage);
    public Boolean hasStorage();
    public A withNewStorage(String arg1);
    public A withNewStorage(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources getSubresources();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources buildSubresources();
    public A withSubresources(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources item);
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources item);
    public interface AdditionalPrinterColumnsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>> {

        public N and();
        public N endAdditionalPrinterColumn();    }


    public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<CustomResourceDefinitionVersionFluent.SchemaNested<N>> {

        public N and();
        public N endSchema();    }


    public interface SubresourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourcesFluent<CustomResourceDefinitionVersionFluent.SubresourcesNested<N>> {

        public N and();
        public N endSubresources();    }


}

==> kubernetes-model-apiextensions-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionVersionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionVersionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<A>> extends Fluent<A> {


    public A addToAdditionalPrinterColumns(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public A setToAdditionalPrinterColumns(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
    public A addAllToAdditionalPrinterColumns(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> items);
    public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
    public A removeAllFromAdditionalPrinterColumns(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> items);
    public A removeMatchingFromAdditionalPrinterColumns(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> getAdditionalPrinterColumns();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean hasMatchingAdditionalPrinterColumn(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public A withAdditionalPrinterColumns(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition> additionalPrinterColumns);
    public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... additionalPrinterColumns);
    public Boolean hasAdditionalPrinterColumns();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition item);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
    public CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionBuilder> predicate);
    public Boolean isDeprecated();
    public A withDeprecated(Boolean deprecated);
    public Boolean hasDeprecated();
    public A withNewDeprecated(String arg1);
    public A withNewDeprecated(boolean arg1);
    public String getDeprecationWarning();
    public A withDeprecationWarning(String deprecationWarning);
    public Boolean hasDeprecationWarning();
    public A withNewDeprecationWarning(String arg1);
    public A withNewDeprecationWarning(StringBuilder arg1);
    public A withNewDeprecationWarning(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation getSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation buildSchema();
    public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation schema);
    public Boolean hasSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation item);
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchema();
    public CustomResourceDefinitionVersionFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation item);
    public Boolean isServed();
    public A withServed(Boolean served);
    public Boolean hasServed();
    public A withNewServed(String arg1);
    public A withNewServed(boolean arg1);
    public Boolean isStorage();
    public A withStorage(Boolean storage);
    public Boolean hasStorage();
    public A withNewStorage(String arg1);
    public A withNewStorage(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSubresources instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources getSubresources();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources buildSubresources();
    public A withSubresources(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources subresources);
    public Boolean hasSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> withNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources item);
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresources();
    public CustomResourceDefinitionVersionFluent.SubresourcesNested<A> editOrNewSubresourcesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresources item);
    public interface AdditionalPrinterColumnsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<CustomResourceDefinitionVersionFluent.AdditionalPrinterColumnsNested<N>> {

            public N and();
            public N endAdditionalPrinterColumn();    }


    public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<CustomResourceDefinitionVersionFluent.SchemaNested<N>> {

            public N and();
            public N endSchema();    }


    public interface SubresourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourcesFluent<CustomResourceDefinitionVersionFluent.SubresourcesNested<N>> {

            public N and();
            public N endSubresources();    }


}
